@@ -44,6 +44,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
     from parsons.mailchimp.mailchimp import Mailchimp
     from parsons.zoom.zoom import Zoom
     from parsons.action_network.action_network import ActionNetwork
+    from parsons.pdi.pdi import PDI
 
     __all__ = [
         'VAN',
@@ -82,6 +83,7 @@ if not os.environ.get('PARSONS_SKIP_IMPORT_ALL'):
         'Mailchimp',
         'Zoom',
         'ActionNetwork',
+        'PDI',
     ]
 
 # Define the default logging config for Parsons and its submodules. For now the
