@@ -154,8 +154,8 @@ class ETL(object):
 
         for v in petl.values(self.table, column):
 
-            if len(str(v)) > max_width:
-                max_width = len(str(v))
+            if len(str(v).encode('utf-8')) > max_width:
+                max_width = len(str(v).encode('utf-8'))
 
         return max_width
 
@@ -168,10 +168,16 @@ class ETL(object):
             `Parsons Table` and also updates self
         """
 
+        # If we don't have any rows, don't bother trying to convert things
+        if self.num_rows == 0:
+            return self
+
         cols = self.get_columns_type_stats()
 
         for col in cols:
-            if len(col['type']) > 1 or col['type'][0] != 'str':
+            # If there's more than one type (or no types), convert to str
+            # Also if there is one type and it's not str, convert to str
+            if len(col['type']) != 1 or col['type'][0] != 'str':
                 self.convert_column(col['name'], str)
 
         return self
@@ -929,3 +935,16 @@ class ETL(object):
         self.table = petl.sort(self.table, key=columns, reverse=reverse)
 
         return self
+
+    def set_header(self, new_header):
+        """
+        Replace the header row of the table.
+
+        `Args:`
+            new_header: list
+                List of new header column names
+        `Returns:`
+            `Parsons Table` and also updates self
+        """
+        self.table = petl.setheader(self.table, new_header)
+        return self
