@@ -78,6 +78,13 @@ class TestParsonsTable(unittest.TestCase):
 
         assert_matching_tables(self.tbl, tbl_materialized)
 
+    def test_materialize_to_file(self):
+        # Simple test that materializing doesn't change the table
+        tbl_materialized = Table(self.lst_dicts)
+        tbl_materialized.materialize_to_file()
+
+        assert_matching_tables(self.tbl, tbl_materialized)
+
     def test_empty_column(self):
         # Test that returns True on an empty column and False on a populated one.
 
@@ -747,3 +754,10 @@ class TestParsonsTable(unittest.TestCase):
         new_tbl = tbl.set_header(['one'])
 
         self.assertEqual(new_tbl[0], {'one': 1})
+
+    def test_bool(self):
+        empty = Table()
+        not_empty = Table([{'one': 1, 'two': 2}])
+
+        self.assertEqual(not empty, True)
+        self.assertEqual(not not_empty, False)
